Source https://userweb.cs.txstate.edu/~burtscher/research/FPC/

FPC is a fast and effective lossless compressor/decompressor for IEEE 754 64-bit double-precision floating-point data.

The source code in file fpc.c can be compiled into an executable called fpc as follows:

gcc -O3 fpc.c -o fpc

The executable compresses/decompresses data with level x from the standard input and writes the result to the standard output. 
x is a positive integer that specifies the internal table size (2x+4 bytes).  Larger x typically result in better compression ratios but slower processing.

To compress the file file.in with level 20 and store the result in a file called file.fpc, enter:

./fpc 20 < file.in > file.fpc

To decompress the file file.fpc and store the result in file file.out, enter:

./fpc < file.fpc > file.out

Note that the raw data file has to be a multiple of 8 bytes long and must contain nothing but binary double-precision values. 
Only little-endian systems are supported.  FPC works particularly well on 64-bit machines and on hard-to-compress data.